////////////////////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2002-2013 Unreal Streaming Technologies
//
// URTSPClientSrc DirectShow filter SDK 
//
////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

////////////////////////////////////////////////////////////////////////////////////////////
// Custom RTSP error DirectShow event ID
// (HRESULT, void) : application
// Stream aborted because of RTSP error
#define EC_RTSP_SOURCE_ERROR (EC_USER + 1) 


////////////////////////////////////////////////////////////////////////////////////////////
// URTSPClientSrc DirectShow source filter class ID
// {F8F42929-B668-46d1-AE0A-8E9DF33E7F5A}
DEFINE_GUID(CLSID_URTSPClientSrc,
            0xf8f42929, 0xb668, 0x46d1, 0xae, 0xa, 0x8e, 0x9d, 0xf3, 0x3e, 0x7f, 0x5a);

// URTSPClientSrc IUErrorDescriptionProvider interface ID
// {FB929C0F-3433-4099-B2EC-152894B0B9AC}
DEFINE_GUID(IID_IUErrorDescriptionProvider, 
            0xfb929c0f, 0x3433, 0x4099, 0xb2, 0xec, 0x15, 0x28, 0x94, 0xb0, 0xb9, 0xac);


////////////////////////////////////////////////////////////////////////////////////////////
// IUErrorDescriptionProvider interface method to get error description in English
DECLARE_INTERFACE_(IUErrorDescriptionProvider, IUnknown)
{
    STDMETHOD(GetDescription)(THIS_ HRESULT hrError, 
                                    BSTR*   pbstrDescription) PURE;
};

struct __declspec(uuid("FB929C0F-3433-4099-B2EC-152894B0B9AC")) IUErrorDescriptionProvider;


////////////////////////////////////////////////////////////////////////////////////////////
// URTSPClientSrc error codes
#define _FACILITY_WINDOWS_               0x8
#define _FACILITY_UNREAL_                0xFFF
#define _FACILITY_ITF_                   0x4

//
// Define the severity codes
//
#define _STATUS_SEVERITY_SUCCESS_        0x0
#define _STATUS_SEVERITY_COError_        0x2

//
// MessageId: E_U_RTSP_BAD_REQUEST
//
// MessageText:
//
// RTSP server received bad/malformed request
//
#define E_U_RTSP_BAD_REQUEST             ((HRESULT)0x8FFF0700L)

//
// MessageId: E_U_RTSP_UNAUTHORIZED
//
// MessageText:
//
// RTSP server cannot authorize client. Wrong or no credentials have been sent.
//
#define E_U_RTSP_UNAUTHORIZED            ((HRESULT)0x8FFF0701L)

//
// MessageId: E_U_RTSP_PAYMENT_REQUIRED
//
// MessageText:
//
// Payment required
//
#define E_U_RTSP_PAYMENT_REQUIRED        ((HRESULT)0x8FFF0702L)

//
// MessageId: E_U_RTSP_FORBIDDEN
//
// MessageText:
//
// RTSP server denied access
//
#define E_U_RTSP_FORBIDDEN               ((HRESULT)0x8FFF0703L)

//
// MessageId: E_U_RTSP_NOT_FOUND
//
// MessageText:
//
// Client sent bad/malformed RTSP URL
//
#define E_U_RTSP_NOT_FOUND               ((HRESULT)0x8FFF0704L)

//
// MessageId: E_U_RTSP_METHOD_NOT_ALLOWED
//
// MessageText:
//
// RTSP server does not allow request method used
//
#define E_U_RTSP_METHOD_NOT_ALLOWED      ((HRESULT)0x8FFF0705L)

//
// MessageId: E_U_RTSP_NOT_ACCEPTABLE
//
// MessageText:
//
// RTSP server response is not acceptable
//
#define E_U_RTSP_NOT_ACCEPTABLE          ((HRESULT)0x8FFF0706L)

//
// MessageId: E_U_RTSP_AUTHENTICATION_REQUIRED
//
// MessageText:
//
// Client must first authenticate itself with the proxy
//
#define E_U_RTSP_AUTHENTICATION_REQUIRED ((HRESULT)0x8FFF0707L)

//
// MessageId: E_U_RTSP_REQUEST_TIMEDOUT
//
// MessageText:
//
// RTSP server timed out waiting for the request
//
#define E_U_RTSP_REQUEST_TIMEDOUT        ((HRESULT)0x8FFF0708L)

//
// MessageId: E_U_RTSP_CONFLICT
//
// MessageText:
//
// Client request could not be processed because of conflict in the request
//
#define E_U_RTSP_CONFLICT                ((HRESULT)0x8FFF0709L)

//
// MessageId: E_U_RTSP_GONE
//
// MessageText:
//
// Resource requested is no longer available and will not be available again
//
#define E_U_RTSP_GONE                    ((HRESULT)0x8FFF070AL)

//
// MessageId: E_U_RTSP_LENGTH_REQUIRED
//
// MessageText:
//
// Client's request did not specify the length of its content, which is required by the requested resource
//
#define E_U_RTSP_LENGTH_REQUIRED         ((HRESULT)0x8FFF070BL)

//
// MessageId: E_U_RTSP_PRECONDITION_FAILD
//
// MessageText:
//
// RTSP server does not meet one of the preconditions that the client put on the request
//
#define E_U_RTSP_PRECONDITION_FAILD      ((HRESULT)0x8FFF070CL)

//
// MessageId: E_U_RTSP_REQUEST_ENTITY_TOO_LARGE
//
// MessageText:
//
// Client request is larger than RTSP server is willing or able to process
//
#define E_U_RTSP_REQUEST_ENTITY_TOO_LARGE ((HRESULT)0x8FFF070DL)

//
// MessageId: E_U_RTSP_REQUEST_URI_TOO_LONG
//
// MessageText:
//
// The URI client provided was too long for the server to process
//
#define E_U_RTSP_REQUEST_URI_TOO_LONG    ((HRESULT)0x8FFF070EL)

//
// MessageId: E_U_RTSP_PARAMETER_NOT_UNDERSTOOD
//
// MessageText:
//
// RTSP server does not understand URL parameter
//
#define E_U_RTSP_PARAMETER_NOT_UNDERSTOOD ((HRESULT)0x8FFF0733L)

//
// MessageId: E_U_RTSP_CONFERENCE_NOT_FOUND
//
// MessageText:
//
// Conference does not exist
//
#define E_U_RTSP_CONFERENCE_NOT_FOUND    ((HRESULT)0x8FFF0734L)

//
// MessageId: E_U_RTSP_NOT_ENOUGH_BANDWIDTH
//
// MessageText:
//
// Not Enough Bandwidth
//
#define E_U_RTSP_NOT_ENOUGH_BANDWIDTH    ((HRESULT)0x8FFF0735L)

//
// MessageId: E_U_RTSP_SESSION_NOT_FOUND
//
// MessageText:
//
// RTSP session that the client specified does not exist on the server
//
#define E_U_RTSP_SESSION_NOT_FOUND       ((HRESULT)0x8FFF0736L)

//
// MessageId: E_U_RTSP_METHOD_NOT_VALID
//
// MessageText:
//
// Method not valid in current RTSP server state
//
#define E_U_RTSP_METHOD_NOT_VALID        ((HRESULT)0x8FFF0737L)

//
// MessageId: E_U_RTSP_HEADER_FIELD_NOT_VALID
//
// MessageText:
//
// Request header field that the client specified is not valid for RTSP resource
//
#define E_U_RTSP_HEADER_FIELD_NOT_VALID  ((HRESULT)0x8FFF0738L)

//
// MessageId: E_U_RTSP_INVALID_RANGE
//
// MessageText:
//
// Client specified invalid media play range
//
#define E_U_RTSP_INVALID_RANGE           ((HRESULT)0x8FFF0739L)

//
// MessageId: E_U_RTSP_PARAMETER_IS_READ_ONLY
//
// MessageText:
//
// Parameter is read-only
//
#define E_U_RTSP_PARAMETER_IS_READ_ONLY  ((HRESULT)0x8FFF073AL)

//
// MessageId: E_U_RTSP_AGGREGATE_OPERATION_NOT_ALLOWED
//
// MessageText:
//
// Aggregate operation not allowed
//
#define E_U_RTSP_AGGREGATE_OPERATION_NOT_ALLOWED ((HRESULT)0x8FFF073BL)

//
// MessageId: E_U_RTSP_ONLY_AGGREGATE_OPERATION_ALLOWED
//
// MessageText:
//
// Only aggregate operation allowed
//
#define E_U_RTSP_ONLY_AGGREGATE_OPERATION_ALLOWED ((HRESULT)0x8FFF073CL)

//
// MessageId: E_U_RTSP_UNSUPPORTED_TRANSPORT
//
// MessageText:
//
// RTSP server does not support transport protocol that the client used
//
#define E_U_RTSP_UNSUPPORTED_TRANSPORT   ((HRESULT)0x8FFF073DL)

//
// MessageId: E_U_RTSP_DESTINATION_UNREACHABLE
//
// MessageText:
//
// Destination unreachable. Network congestion/gateway problem.
//
#define E_U_RTSP_DESTINATION_UNREACHABLE ((HRESULT)0x8FFF073EL)

//
// MessageId: E_U_RTSP_INTERNAL_SERVER_ERROR
//
// MessageText:
//
// Internal RTSP server error
//
#define E_U_RTSP_INTERNAL_SERVER_ERROR   ((HRESULT)0x8FFF0764L)

//
// MessageId: E_U_RTSP_NOT_IMPLEMENTED
//
// MessageText:
//
// RTSP server either does not recognise the request method, or it lacks the ability to fulfill the request
//
#define E_U_RTSP_NOT_IMPLEMENTED         ((HRESULT)0x8FFF0765L)

//
// MessageId: E_U_RTSP_BAD_GATEWAY
//
// MessageText:
//
// RTSP server was acting as a gateway or proxy and received an invalid response from the upstream server
//
#define E_U_RTSP_BAD_GATEWAY             ((HRESULT)0x8FFF0766L)

//
// MessageId: E_U_RTSP_SERVICE_UNAVAILABLE
//
// MessageText:
//
// RTSP server is currently unavailable
//
#define E_U_RTSP_SERVICE_UNAVAILABLE     ((HRESULT)0x8FFF0767L)

//
// MessageId: E_U_RTSP_GATEWAY_TIME_OUT
//
// MessageText:
//
// RTSP server was acting as a gateway or proxy and did not receive a timely response from the upstream server
//
#define E_U_RTSP_GATEWAY_TIME_OUT        ((HRESULT)0x8FFF0768L)

//
// MessageId: E_U_RTSP_VERSION_NOT_SUPPORTED
//
// MessageText:
//
// RTSP server does not support the RTSP protocol version used in the client request
//
#define E_U_RTSP_VERSION_NOT_SUPPORTED   ((HRESULT)0x8FFF0769L)

//
// MessageId: E_U_RTSP_OPTION_NOT_SUPPORTED
//
// MessageText:
//
// RTSP server does not support this option
//
#define E_U_RTSP_OPTION_NOT_SUPPORTED    ((HRESULT)0x8FFF0797L)

//
// MessageId: E_U_RTSP_UNSUPPORTED_VIDEO_MEDIA_TYPE
//
// MessageText:
//
// Client does not support this RTSP server video media type/format
//
#define E_U_RTSP_UNSUPPORTED_VIDEO_MEDIA_TYPE ((HRESULT)0x8FFF0798L)

//
// MessageId: E_U_RTSP_UNSUPPORTED_AUDIO_MEDIA_TYPE
//
// MessageText:
//
// Client does not support this RTSP server audio media type/format
//
#define E_U_RTSP_UNSUPPORTED_AUDIO_MEDIA_TYPE ((HRESULT)0x8FFF0799L)


////////////////////////////////////////////////////////////////////////////////////////////